# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need Module::Build::Tiny ≥ 0.035
%global old_mbt %(perl -MModule::Build::Tiny -e 'print (($Module::Build::Tiny::VERSION < 0.035) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to patch the test suite unless we have Test::More ≥ 0.88
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Readonly
Version:	2.05
Release:	1.%{__distinit}%{__distvers}
Summary:	Facility for creating read-only scalars, arrays, hashes
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Readonly/
Source0:	http://search.cpan.org/CPAN/authors/id/S/SA/SANKO/Readonly-%{version}.tar.gz
Patch0:		Readonly-2.05-interpreter.patch
Patch1:		Readonly-2.04-old-M:B:T.patch
Patch2:		Readonly-2.05-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(Module::Build::Tiny) >= 0.030
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Storable)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(warnings)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Carp)
Requires:	perl(Storable)

# Obsolete/provide old -tests subpackage (can be removed in F19 development cycle)
Obsoletes:	perl-Readonly-tests < %{version}-%{release}
Provides:	perl-Readonly-tests = %{version}-%{release}

%description
Readonly provides a facility for creating non-modifiable scalars,
arrays, and hashes. Any attempt to modify a Readonly variable throws
an exception.

Readonly:
* Creates scalars, arrays (not lists), and hashes
* Creates variables that look and work like native perl variables
* Creates global or lexical variables
* Works at run-time or compile-time
* Works with deep or shallow data structures
* Prevents reassignment of Readonly variables

%prep
%setup -q -n Readonly-%{version}

# Fix script interpreter for test suite since we're packaging it
%patch0

# We don't really need Module::Build::Tiny ≥ 0.035
%if %{old_mbt}
%patch1
%endif

# We need to patch the test suite unless we have Test::More ≥ 0.88
%if %{old_test_more}
%patch2
%endif

%build
perl Build.PL --installdirs=vendor
./Build

%install
rm -rf %{buildroot}
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} %{buildroot}

%check
./Build test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README.md eg/benchmark.pl t/
%{perl_vendorlib}/Readonly.pm
%{_mandir}/man3/Readonly.3*

%changelog
* Mon Jun 13 2016 Paul Howarth <paul@city-fan.org> - 2.05-1
- Update to 2.05
  - Fix deref when using the stupid and utterly unnecessary Readonly::Clone
- BR: perl-generators where available
- Add patch to support building with Test::More < 0.88
- Update patches as needed

* Sat May  7 2016 Paul Howarth <paul@city-fan.org> - 2.04-1
- Update to 2.04
  - Create mutable clones of readonly structures with Readonly::Clone (GH#13)
  - Minor typo fix (GH#21)
  - Rewording some documentation
  - No longer require an explicit version of perl in META.json or cpanfile
  - Quiet compile time warnings about function prototypes and vars being used
    only once
- Update patches as needed

* Thu Feb 25 2016 Paul Howarth <paul@city-fan.org> - 2.01-1
- Update to 2.01
  - Disallow initialization of Readonly variables by assignment, allowed by
    Perl prototype changes in v5.16; assignment initialization of scalars sets
    scalar variables to undef and lists and hashes initialized by assignment
    are not read only
- Use %%license where possible
- Upstream switched to Module::Build::Tiny flow
- Update interpreter patch

* Thu Jul  3 2014 Paul Howarth <paul@city-fan.org> - 2.00-1
- Update to 2.00
  - Deprecation of Readonly::XS as a requirement for fast, readonly scalars is
    complete
- Upstream dropped TODO file

* Mon Jun 30 2014 Paul Howarth <paul@city-fan.org> - 1.610-1
- Update to 1.61
  - Fix array and hash tie() while in XS mode (exposed by Params::Validate
    tests)
  - Fix implicit undef value regression
    (https://github.com/sanko/readonly/issues/8)
  - Normal constants (strings, numbers) do not appear to be read-only to
    Internals::SvREADONLY($) but perl itself doesn't miss a beat when you
    attempt to assign a value to them; fixing test regression in
    t/general/reassign.t
  - Minor documentation fixes (spell check, etc.)
    (https://github.com/sanko/readonly/issues/7)
- Update shellbang patch

* Thu Jun 26 2014 Paul Howarth <paul@city-fan.org> - 1.500.0-1
- Update to v1.500.0
  - Re-release with new version number

* Wed Jun 25 2014 Paul Howarth <paul@city-fan.org> - 1.5.0-1
- Update to v1.5.0
  - Readonly::XS is no longer needed
  - Typo fix (CPAN RT#86350)
  - Array and Hash scalar references were not made deeply readonly
    (CPAN RT#37864)
  - Upstream magic related bugs were reported to p5p and fixed in perl itself
    so we can resolve the following local issues:
    - CPAN RT#24216 ('looks_like_number' doesn't handle Readonly properly)
    - CPAN RT#29487 (magical variable bug in perl 5.8.5)
    - CPAN RT#36653 (Readonly scalar as class name sometimes undefined)
    - CPAN RT#57382 (tie-related bug in perl's core)
    - CPAN RT#70167 (unaccessed read-only variables are undef in select calls)
  - Reported Perl RT#120122 (tie + smartmatch bug) upstream to p5p; will
    eventually resolve local (CPAN RT#59256)
  - Use readonly support exposed in Internals on perl ≥ 5.8.0
  - Checking Readonly::XS::Okay is no longer suggested... never should have
    been
- Update shellbang patch

* Tue Nov 26 2013 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04
  - Module now maintained by Sanko Robinson; please see TODO for a possible set
    of changes to this module that may affect code written for old, pre-perl
    5.14.0 platforms!
  - Don't install benchmark.pl (CPAN RT#16167)
- This release by SANKO -> update source URL
- Switch to Module::Build flow
- Update shellbang patch

* Sun Aug 26 2012 Paul Howarth <paul@city-fan.org> - 1.03-21
- BR:/R: perl(Carp)

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.03-19
- Drop buildreqs perl(strict) and perl(vars), not dual-lived
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Mar  1 2012 Paul Howarth <paul@city-fan.org> - 1.03-18
- Include test suite as %%doc
- No need to remove empty directories from buildroot
- Add buildreqs for Perl core modules that might be dual-lived
- Patch script interpreter for test suite

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 1.03-16
- Rebuild for perl 5.14.1 in Rawhide
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.03-13
- Rebuild for perl 5.12.1 in Rawhide

* Wed Jun  2 2010 Paul Howarth <paul@city-fan.org> - 1.03-12
- Fix dist tag for RHEL-6 Beta

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> - 1.03-11
- Import from Fedora

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.03-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.03-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.03-8
- Rebuild for perl 5.10 (again)

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.03-7
- Rebuild for new perl

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.03-6.2
- Add BR: perl(Test::More)

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.03-6.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Wed Oct 04 2006 Chris Weyl <cweyl@alumni.drew.edu> - 1.03-6
- Add explict requires on perl(Readonly::XS); perl(Readonly::XS) is available
  for all architectures Fedora supports, so there's no good reason to not
  require it
- Spec file rework

* Tue Sep 19 2006 Chris Weyl <cweyl@alumni.drew.edu> - 1.03-5
- Bump for mass rebuild

* Thu Dec 08 2005 Michael A. Peters <mpeters@mac.com> - 1.03-4
- Remove requires on perl-Readonly-XS

* Thu Dec 08 2005 Michael A. Peters <mpeters@mac.com> - 1.03-3
- Fix license and BuildRequires, use %%{?_smp_mflags} with make

* Sat Nov 12 2005 Michael A. Peters <mpeters@mac.com> - 1.03-2
- Separate out perl-Readonly-XS into its own package
- Package benchmark.pl as a doc

* Mon Nov 7 2005 Michael A. Peters <mpeters@mac.com> - 1.03-1
- Initial spec file
